window.Gleam.initSearch([{"doc":"promgleam","title":"promgleam","content":"# PromGleam\n\n[![Package Version](https://img.shields.io/hexpm/v/promgleam)](https://hex.pm/packages/promgleam)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/promgleam/)\n\nA [Prometheus](https://prometheus.io) client library for Gleam, based on [prometheus.erl](https://github.com/deadtrickster/prometheus.erl)\n\n## Installation\n\n```sh\ngleam add promgleam\n```\n\n## Examples\n\n- [PromGleam integration with Wisp](https://github.com/dios-david/promgleam/tree/main/examples/wisp/)\n\n## Quick guide\n\n### Creating and incrementing a `Counter`\n\n&gt; A counter is a cumulative metric that represents a single monotonically increasing counter whose value can only increase or be reset to zero on restart. For example, you can use a counter to represent the number of requests served, tasks completed, or errors.\n[(Source)](https://prometheus.io/docs/concepts/metric_types/#counter)\n\n```gleam\nimport promgleam/metrics/counter.{create_counter, increment_counter}\n\ncreate_counter(\n  registry: &quot;default&quot;,\n  name: &quot;http_requests_total&quot;,\n  help: &quot;Total number of HTTP requests&quot;,\n  labels: [ &quot;method&quot;, &quot;route&quot;, &quot;status&quot; ],\n)\n\nincrement_counter(\n  registry: &quot;default&quot;,\n  name: &quot;http_requests_total&quot;,\n  labels: [ &quot;GET&quot;, &quot;/&quot;, &quot;200&quot; ],\n  value: 1,\n)\n```\n\n### Creating and setting a `Gauge`\n\n&gt; A gauge is a metric that represents a single numerical value that can arbitrarily go up and down.\nGauges are typically used for measured values like temperatures or current memory usage, but also &quot;counts&quot; that can go up and down, like the number of concurrent requests.\n[(Source)](https://prometheus.io/docs/concepts/metric_types/#gauge)\n\n```gleam\nimport promgleam/metrics/gauge.{create_gauge, set_gauge}\n\ncreate_gauge(\n  registry: &quot;default&quot;,\n  name: &quot;cache_size&quot;,\n  help: &quot;Number of items in the cache&quot;,\n  labels: [ &quot;cache_name&quot; ],\n)\n\nset_gauge(\n  registry: &quot;default&quot;,\n  name: &quot;cache_size&quot;,\n  labels: [ &quot;image_cache&quot; ],\n  value: 123,\n)\n```\n\n### Creating and observing a `Histogram`\n\n&gt; A histogram samples observations (usually things like request durations or response sizes) and counts them in configurable buckets. It also provides a sum of all observed values.\n[(Source)](https://prometheus.io/docs/concepts/metric_types/#histogram)\n\n```gleam\nimport promgleam/metrics/histogram.{create_histogram, observe_histogram}\n\ncreate_histogram(\n  registry: &quot;default&quot;,\n  name: &quot;http_request_duration_seconds&quot;,\n  help: &quot;Duration of HTTP requests in seconds&quot;,\n  labels: [ &quot;method&quot;, &quot;route&quot;, &quot;status&quot; ],\n  buckets: [ 0.1, 0.25, 0.5, 1.0, 1.5 ],\n)\n\nobserve_histogram(\n  registry: &quot;default&quot;,\n  name: &quot;http_request_duration_seconds&quot;,\n  labels: [ &quot;GET&quot;, &quot;/&quot;, &quot;200&quot; ],\n  value: 0.23,\n)\n```\n\nBoth `measure_histogram` and `measure_histogram_seconds` can be used to wrap a function to\nautomatically observe the execution time whenever the function is invoked, rather than manually\nmeasuring it and reporting it with `observe_histogram`.\n\n```gleam\nimport promgleam/metrics/histogram.{measure_histogram}\n\nfn my_function_to_measure() {\n  use &lt;- measure_histogram(\n    registry: &quot;default&quot;,\n    name: &quot;function_execution_time&quot;,\n    labels: [ &quot;my_function_to_measure&quot; ],\n  )\n\n  // Do something slow here\n}\n```\n\n### Generating buckets\n\nThis library provides utility functions to create `buckets` for a Histogram:\n\n```gleam\nimport promgleam/buckets.{exponential, linear}\n\nexponential(start: 1.0, factor: 2, count: 5) // Ok([1.0, 2.0, 4.0, 8.0, 10.0])\nlinear(start: 1.0, step: 3.0, count: 4) // Ok([1.0, 4.0, 7.0, 10.0])\n```\n### Printing the contents of a metric registry\n\nThis can be done by using one of the `print_as` functions:\n- `print_as_text` - Serialises the registry using the [Prometheus text-based format](https://github.com/prometheus/docs/blob/main/content/docs/instrumenting/exposition_formats.md#text-format-example) into a `String`\n- `print_as_prometheus` - Serialises the registry using the [Prometheus Protobuf format](https://github.com/prometheus/docs/blob/main/content/docs/instrumenting/exposition_formats.md#protobuf-format) into a `BitArray`\n\n```gleam\nimport promgleam/registry.{print_as_text, print_as_protobuf}\n\nprint_as_text(registry_name: &quot;default&quot;)\nprint_as_protobuf(registry_name: &quot;default&quot;)\n```\n\n---\nFurther documentation can be found at &lt;https://hexdocs.pm/promgleam&gt;.\n","url":"index.html"},{"doc":"promgleam/buckets","title":"Buckets","content":"pub type Buckets =\n  List(Float)\n\n\nSynonyms:\npromgleam/buckets.Buckets\npromgleam/buckets Buckets","url":"promgleam/buckets.html#Buckets"},{"doc":"promgleam/buckets","title":"exponential","content":"pub fn exponential(\n  start start: Float,\n  factor factor: Int,\n  count count: Int,\n) -&gt; Result(List(Float), String)\n Creates `count` buckets, where the lowest bucket has an upper bound of `start` and each\n following bucket&#39;s upper bound is `factor` times the previous bucket&#39;s upper bound.\n\n # Examples\n\n \n let assert Ok([1.0, 2.0, 4.0, 8.0]) = exponential(start: 1.0, factor: 2, count: 4)\n \nSynonyms:\npromgleam/buckets.exponential\npromgleam/buckets exponential","url":"promgleam/buckets.html#exponential"},{"doc":"promgleam/buckets","title":"linear","content":"pub fn linear(\n  start start: Float,\n  step step: Float,\n  count count: Int,\n) -&gt; Result(List(Float), String)\n Creates `count` buckets, each `step` wide, where the lowest bucket has an upper bound of\n `start`.\n\n # Examples\n\n \n let assert Ok([1.0, 4.0, 7.0, 10.0]) = linear(start: 1.0, step: 3.0, count: 4)\n \nSynonyms:\npromgleam/buckets.linear\npromgleam/buckets linear","url":"promgleam/buckets.html#linear"},{"doc":"promgleam/buckets","title":"promgleam/buckets","content":" Utility functions to generate buckets for Histogram metrics.","url":"promgleam/buckets.html"},{"doc":"promgleam/metrics/counter","title":"create_counter","content":"pub fn create_counter(\n  registry registry: String,\n  name name: String,\n  help help: String,\n  labels labels: List(String),\n) -&gt; Result(Nil, String)\n Creates a new Counter metric.\n\n # Examples\n\n \n create_counter(\n   registry: &quot;default&quot;,\n   name: &quot;http_requests_total&quot;,\n   help: &quot;Total number of HTTP requests&quot;,\n   labels: [ &quot;method&quot;, &quot;route&quot;, &quot;status&quot; ],\n )\n \nSynonyms:\npromgleam/metrics/counter.create_counter\npromgleam/metrics/counter create_counter","url":"promgleam/metrics/counter.html#create_counter"},{"doc":"promgleam/metrics/counter","title":"increment_counter","content":"pub fn increment_counter(\n  registry registry: String,\n  name name: String,\n  labels labels: List(String),\n  value value: Int,\n) -&gt; Result(Nil, String)\n Increments the Counter with the given value.\n\n # Examples\n \n increment_counter(\n   registry: &quot;default&quot;,\n   name: &quot;http_requests_total&quot;,\n   labels: [ &quot;GET&quot;, &quot;/&quot;, &quot;200&quot; ],\n   value: 1,\n )\n \nSynonyms:\npromgleam/metrics/counter.increment_counter\npromgleam/metrics/counter increment_counter","url":"promgleam/metrics/counter.html#increment_counter"},{"doc":"promgleam/metrics/counter","title":"promgleam/metrics/counter","content":" A counter is a cumulative metric that represents a single monotonically increasing counter whose\n value can only increase or be reset to zero on restart. For example, you can use a counter to\n represent the number of requests served, tasks completed, or errors.\n\n Do not use a counter to expose a value that can decrease. For example, do not use a counter for\n the number of currently running processes; instead use a gauge.","url":"promgleam/metrics/counter.html"},{"doc":"promgleam/metrics/gauge","title":"create_gauge","content":"pub fn create_gauge(\n  registry registry: String,\n  name name: String,\n  help help: String,\n  labels labels: List(String),\n) -&gt; Result(Nil, String)\n Creates a new Gauge metric.\n\n # Examples\n\n \n create_gauge(\n   registry: &quot;default&quot;,\n   name: &quot;cache_size&quot;,\n   help: &quot;Number of items in the cache&quot;,\n   labels: [ &quot;cache_name&quot; ],\n )\n \nSynonyms:\npromgleam/metrics/gauge.create_gauge\npromgleam/metrics/gauge create_gauge","url":"promgleam/metrics/gauge.html#create_gauge"},{"doc":"promgleam/metrics/gauge","title":"set_gauge","content":"pub fn set_gauge(\n  registry registry: String,\n  name name: String,\n  labels labels: List(String),\n  value value: Int,\n) -&gt; Result(Nil, String)\n Sets the value of the Gauge.\n\n # Examples\n \n set_gauge(\n   registry: &quot;default&quot;,\n   name: &quot;cache_size&quot;,\n   labels: [ &quot;image_cache&quot; ],\n   value: 123,\n )\n \nSynonyms:\npromgleam/metrics/gauge.set_gauge\npromgleam/metrics/gauge set_gauge","url":"promgleam/metrics/gauge.html#set_gauge"},{"doc":"promgleam/metrics/gauge","title":"promgleam/metrics/gauge","content":" A gauge is a metric that represents a single numerical value that can arbitrarily go\n up and down.\n\n Gauges are typically used for measured values like temperatures or current memory usage, but\n also &quot;counts&quot; that can go up and down, like the number of concurrent requests.","url":"promgleam/metrics/gauge.html"},{"doc":"promgleam/utils","title":"measure","content":"pub fn measure(func: fn() -&gt; a) -&gt; #(Int, a)\n Measures the execution time of a function in milliseconds, then returns that with the function\n return value in a tuple.\n\n # Examples\n\n \n fn my_func() {\n   &quot;wibble&quot;\n }\n\n let assert #(time_taken, &quot;wibble&quot;) = measure(my_func)\n \nSynonyms:\npromgleam/utils.measure\npromgleam/utils measure","url":"promgleam/utils.html#measure"},{"doc":"promgleam/utils","title":"promgleam/utils","content":" Utility functions to perform common tasks which are often needed when dealing with metrics.","url":"promgleam/utils.html"},{"doc":"promgleam/metrics/histogram","title":"create_histogram","content":"pub fn create_histogram(\n  registry registry: String,\n  name name: String,\n  help help: String,\n  labels labels: List(String),\n  buckets buckets: List(Float),\n) -&gt; Result(Nil, String)\n Creates a new Histogram metric.\n\n # Examples\n\n \n create_histogram(\n   registry: &quot;default&quot;,\n   name: &quot;http_request_duration_seconds&quot;,\n   help: &quot;Duration of HTTP requests in seconds&quot;,\n   labels: [ &quot;method&quot;, &quot;route&quot;, &quot;status&quot; ],\n   buckets: [ 0.1, 0.25, 0.5, 1.0, 1.5 ],\n )\n \nSynonyms:\npromgleam/metrics/histogram.create_histogram\npromgleam/metrics/histogram create_histogram","url":"promgleam/metrics/histogram.html#create_histogram"},{"doc":"promgleam/metrics/histogram","title":"measure_histogram","content":"pub fn measure_histogram(\n  registry registry: String,\n  name name: String,\n  labels labels: List(String),\n  func func: fn() -&gt; a,\n) -&gt; Result(a, String)\n Measures a function execution time in milliseconds and observes that in the Histogram.\n\n # Examples\n\n \n fn my_function_to_measure() {\n   use &lt;- measure_histogram(\n     registry: &quot;default&quot;,\n     name: &quot;function_execution_time&quot;,\n     labels: [ &quot;my_function_to_measure&quot; ],\n   )\n\n   // Do something slow here\n\n   &quot;return_value&quot;\n }\n\n let assert Ok(&quot;return_value&quot;) = my_function_to_measure()\n \n\n \n fn my_function_to_measure() {\n   // Do something slow here\n\n   &quot;return_value&quot;\n }\n\n let assert Ok(&quot;return_value&quot;) =\n   my_function_to_measure\n   |&gt; measure_histogram(\n     registry: &quot;default&quot;,\n     name: &quot;function_execution_time&quot;,\n     labels: [ &quot;my_function_to_measure&quot; ],\n     func: _\n   )\n \nSynonyms:\npromgleam/metrics/histogram.measure_histogram\npromgleam/metrics/histogram measure_histogram","url":"promgleam/metrics/histogram.html#measure_histogram"},{"doc":"promgleam/metrics/histogram","title":"measure_histogram_seconds","content":"pub fn measure_histogram_seconds(\n  registry registry: String,\n  name name: String,\n  labels labels: List(String),\n  func func: fn() -&gt; a,\n) -&gt; Result(a, String)\n Measures a function execution time in seconds and observes that in the Histogram.\n\n # Examples\n\n \n fn my_function_to_measure() {\n   use &lt;- measure_histogram_seconds(\n     registry: &quot;default&quot;,\n     name: &quot;function_execution_time&quot;,\n     labels: [ &quot;my_function_to_measure&quot; ],\n   )\n\n   // Do something slow here\n\n   &quot;return_value&quot;\n }\n\n let assert Ok(&quot;return_value&quot;) = my_function_to_measure()\n \n\n \n fn my_function_to_measure() {\n   // Do something slow here\n\n   &quot;return_value&quot;\n }\n\n let assert Ok(&quot;return_value&quot;) =\n   my_function_to_measure\n   |&gt; measure_histogram_seconds(\n     registry: &quot;default&quot;,\n     name: &quot;function_execution_time&quot;,\n     labels: [ &quot;my_function_to_measure&quot; ],\n     func: _\n   )\n \nSynonyms:\npromgleam/metrics/histogram.measure_histogram_seconds\npromgleam/metrics/histogram measure_histogram_seconds","url":"promgleam/metrics/histogram.html#measure_histogram_seconds"},{"doc":"promgleam/metrics/histogram","title":"observe_histogram","content":"pub fn observe_histogram(\n  registry registry: String,\n  name name: String,\n  labels labels: List(String),\n  value value: Float,\n) -&gt; Result(Nil, String)\n Observes a value in the Histogram.\n\n # Examples\n\n \n observe_histogram(\n   registry: &quot;default&quot;,\n   name: &quot;http_request_duration_seconds&quot;,\n   labels: [ &quot;GET&quot;, &quot;/&quot;, &quot;200&quot; ],\n   value: 0.23,\n )\n \nSynonyms:\npromgleam/metrics/histogram.observe_histogram\npromgleam/metrics/histogram observe_histogram","url":"promgleam/metrics/histogram.html#observe_histogram"},{"doc":"promgleam/metrics/histogram","title":"promgleam/metrics/histogram","content":" A histogram samples observations (usually things like request durations or response sizes)\n and counts them in configurable buckets. It also provides a sum of all observed values.","url":"promgleam/metrics/histogram.html"},{"doc":"promgleam/registry","title":"clear_registry","content":"pub fn clear_registry(name: String) -&gt; Nil\n Removes all the previously registered metrics from a registry.\nSynonyms:\npromgleam/registry.clear_registry\npromgleam/registry clear_registry","url":"promgleam/registry.html#clear_registry"},{"doc":"promgleam/registry","title":"print_as_protobuf","content":"pub fn print_as_protobuf(\n  registry_name registry_name: String,\n) -&gt; BitArray\n Serialises the registry using the [Prometheus Protobuf format](https://github.com/prometheus/docs/blob/main/content/docs/instrumenting/exposition_formats.md#protobuf-format).\nSynonyms:\npromgleam/registry.print_as_protobuf\npromgleam/registry print_as_protobuf","url":"promgleam/registry.html#print_as_protobuf"},{"doc":"promgleam/registry","title":"print_as_text","content":"pub fn print_as_text(\n  registry_name registry_name: String,\n) -&gt; String\n Serialises the registry using the [Prometheus text-based format](https://github.com/prometheus/docs/blob/main/content/docs/instrumenting/exposition_formats.md#text-format-example).\nSynonyms:\npromgleam/registry.print_as_text\npromgleam/registry print_as_text","url":"promgleam/registry.html#print_as_text"},{"doc":"promgleam/registry","title":"promgleam/registry","content":" Functions to interact with a metric registry.","url":"promgleam/registry.html"}]);